@@ -27,7 +27,7 @@ use std::io::{self, stdin, ErrorKind, IsTerminal, Read, Write};
 use std::path::{Component, PathBuf};
 use std::process::exit;
 
-use ansiterm::{ANSIStrings, Style};
+use nu_ansi_term::{AnsiStrings as ANSIStrings, Style};
 
 use crate::fs::feature::git::GitCache;
 use crate::fs::filter::GitIgnore;
@@ -53,11 +53,6 @@ fn main() {
 
     logger::configure(env::var_os(vars::EZA_DEBUG).or_else(|| env::var_os(vars::EXA_DEBUG)));
 
-    #[cfg(windows)]
-    if let Err(e) = ansiterm::enable_ansi_support() {
-        warn!("Failed to enable ANSI support: {}", e);
-    }
-
     let stdout_istty = io::stdout().is_terminal();
 
     let mut input = String::new();
